pub enum EHAction {
None,
Cleanup(*const u8),
Catch(*const u8),
Filter(*const u8),
Terminate,
}Variants
None
Cleanup(*const u8)
Destructors should be executed when stack unwinds.
Catch(*const u8)
Stack unwind should be stopped as the exception is going to be caught by catch_unwind.
Filter(*const u8)
Stack unwind should be stopped for termination (UnwindAction::Terminate).
Note that due to inlining the landing pad can execute destructors before terminating. So
this is different from Terminate.
Handling of this is mostly identical to Catch; except that Rust frames that have no
destructors but only UnwindAction::Terminate is considered as plain-old-frame (POF) and
forced unwind is allowed to unwind past it; so this is treated as None during forced unwind.
Terminate
Process should be terminated as the call site does not permit unwinding.